duct.database.datalog

Protocols and methods for accessing a generic Datomic-flavored datalog database, such as Datomic, DataScript, Datalevin or Datahike.

Protocols and methods for accessing a generic Datomic-flavored datalog
database, such as Datomic, DataScript, Datalevin or Datahike.
raw docstring

Connectioncljprotocol

A database connection that can have transactions written to it or have a queryable database retrieved from it.

A database connection that can have transactions written to it or have
a queryable database retrieved from it.

-dbclj

(-db conn)

Return a queryable database.

Return a queryable database.

-transact!clj

(-transact! conn tx-data)

Add a new transaction to the database via a database connection.

Add a new transaction to the database via a database connection.
sourceraw docstring

Databasecljprotocol

A database that can be queried via Datomic-flavored datalog.

A database that can be queried via Datomic-flavored datalog.

-qclj

(-q db query inputs)

Run a datalog query on a database with the supplied inputs.

Run a datalog query on a database with the supplied inputs.
sourceraw docstring

dbclj

(db conn)

Get a database from a database connection. This database can be queried with q.

Get a database from a database connection. This database can be queried
with [[q]].
sourceraw docstring

qclj

(q query db & inputs)

Run a datalog query on a database with the supplied inputs.

Run a datalog query on a database with the supplied inputs.
sourceraw docstring

transact!clj

(transact! conn tx-data)

Add a new transaction to the database via a database connection.

Add a new transaction to the database via a database connection.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries