Protocols and methods for accessing a generic Datomic-flavored datalog database, such as Datomic, DataScript, Datalevin or Datahike.
Protocols and methods for accessing a generic Datomic-flavored datalog database, such as Datomic, DataScript, Datalevin or Datahike.
A database connection that can have transactions written to it or have a queryable database retrieved from it.
A database connection that can have transactions written to it or have a queryable database retrieved from it.
(-db conn)Return a queryable database.
Return a queryable database.
(-transact! conn tx-data)Add a new transaction to the database via a database connection.
Add a new transaction to the database via a database connection.
A database that can be queried via Datomic-flavored datalog.
A database that can be queried via Datomic-flavored datalog.
(-q db query inputs)Run a datalog query on a database with the supplied inputs.
Run a datalog query on a database with the supplied inputs.
(db conn)Get a database from a database connection. This database can be queried
with q.
Get a database from a database connection. This database can be queried with [[q]].
(q db query & inputs)Run a datalog query on a database with the supplied inputs.
Run a datalog query on a database with the supplied inputs.
(transact! conn tx-data)Add a new transaction to the database via a database connection.
Add a new transaction to the database via a database connection.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |